@@ -8,9 +8,11 @@ from hein_robots.kinova.kortex import KortexConnection, Base_pb2, ControlConfig_
 
 class KinovaGen3Arm(robot_arms.RobotArm):
     GRIPPER_VELOCITY_STOP_THRESHOLD = 0.01
+    GRIPPER_STOP_WAIT_TIME = 0.5
+    GRIPPER_WAIT_DELAY = 0.05
 
     def __init__(self, host: str = '192.168.1.10', port: int = 10000, username: str = 'admin', password: str = 'admin', connect: bool = True,
-                 default_velocity: float = 250, max_velocity: float = 500, default_joint_velocity: float = 5.0, position_units: str = Units.MILLIMETERS):
+                 default_velocity: float = 250, max_velocity: float = 500, position_units: str = Units.MILLIMETERS):
         self.connection = KortexConnection(host, port, username=username, password=password, connect=connect)
         self.last_feedback = None
         self.last_feedback_time = 0
@@ -20,7 +22,6 @@ class KinovaGen3Arm(robot_arms.RobotArm):
         self._joint_count: Optional[int] = None
         self._default_velocity = default_velocity
         self._max_velocity = max_velocity
-        self.default_joint_velocity = default_joint_velocity
 
     @property
     def position_units(self) -> str:
@@ -257,8 +258,9 @@ class KinovaGen3Arm(robot_arms.RobotArm):
             joint_angle.joint_identifier = joint_id
             joint_angle.value = joint_offsets[joint_id] + joint_positions[joint_id]
 
-        action.reach_joint_angles.constraint.type = Base_pb2.JOINT_CONSTRAINT_SPEED
-        action.reach_joint_angles.constraint.value = self.default_joint_velocity if velocity is None else velocity
+        if velocity is not None:
+            action.reach_joint_angles.constraint.type = Base_pb2.JOINT_CONSTRAINT_SPEED
+            action.reach_joint_angles.constraint.value = velocity
 
         self.connection.execute_action(action, wait=wait, timeout=timeout)
 
@@ -272,8 +274,9 @@ class KinovaGen3Arm(robot_arms.RobotArm):
         joint_angle.joint_identifier = joint_id
         joint_angle.value = joint_offset + position
 
-        action.reach_joint_angles.constraint.type = Base_pb2.JOINT_CONSTRAINT_SPEED
-        action.reach_joint_angles.constraint.value = self.default_joint_velocity if velocity is None else velocity
+        if velocity is not None:
+            action.reach_joint_angles.constraint.type = Base_pb2.JOINT_CONSTRAINT_SPEED
+            action.reach_joint_angles.constraint.value = velocity
 
         self.connection.execute_action(action, wait=wait, timeout=timeout)
 
@@ -306,6 +309,7 @@ class KinovaGen3Arm(robot_arms.RobotArm):
 
         while time.time() - start_time < timeout:
             if abs(self.gripper_velocity) < self.GRIPPER_VELOCITY_STOP_THRESHOLD:
+                time.sleep(self.GRIPPER_STOP_WAIT_TIME)
                 return
 
         raise robot_arms.RobotArmGripperTimeoutError(f'Timeout while waiting for gripper to stop')
@@ -325,5 +329,5 @@ class KinovaGen3Arm(robot_arms.RobotArm):
         self.connection.execute_gripper_command(command)
 
         if wait:
-            time.sleep(0.05)
+            time.sleep(self.GRIPPER_WAIT_DELAY)
             self.wait_for_gripper_stop(timeout=timeout)
